@@ -18,7 +18,7 @@
  * This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY
  * KIND, either express or implied.
  *
- * $Id: sockfilt.c,v 1.51 2008-03-05 18:27:31 yangtse Exp $
+ * $Id: sockfilt.c,v 1.55 2008-10-01 17:34:25 danf Exp $
  ***************************************************************************/
 
 /* Purpose
@@ -119,12 +119,15 @@
 #define DEFAULT_LOGFILE "log/sockfilt.log"
 #endif
 
-const char *serverlogfile = (char *)DEFAULT_LOGFILE;
+const char *serverlogfile = DEFAULT_LOGFILE;
 
-bool verbose = FALSE;
-bool use_ipv6 = FALSE;
-unsigned short port = DEFAULT_PORT;
-unsigned short connectport = 0; /* if non-zero, we activate this mode */
+static bool verbose = FALSE;
+#ifdef ENABLE_IPV6
+static bool use_ipv6 = FALSE;
+#endif
+static const char *ipv_inuse = "IPv4";
+static unsigned short port = DEFAULT_PORT;
+static unsigned short connectport = 0; /* if non-zero, we activate this mode */
 
 enum sockmode {
   PASSIVE_LISTEN,    /* as a server waiting for connections */
@@ -178,29 +181,29 @@ static void install_signal_handlers(void)
 #ifdef SIGHUP
   /* ignore SIGHUP signal */
   if((old_sighup_handler = signal(SIGHUP, SIG_IGN)) == SIG_ERR)
-    logmsg("cannot install SIGHUP handler: 5s", strerror(ERRNO));
+    logmsg("cannot install SIGHUP handler: %s", strerror(ERRNO));
 #endif
 #ifdef SIGPIPE
   /* ignore SIGPIPE signal */
   if((old_sigpipe_handler = signal(SIGPIPE, SIG_IGN)) == SIG_ERR)
-    logmsg("cannot install SIGPIPE handler: 5s", strerror(ERRNO));
+    logmsg("cannot install SIGPIPE handler: %s", strerror(ERRNO));
 #endif
 #ifdef SIGALRM
   /* ignore SIGALRM signal */
   if((old_sigalrm_handler = signal(SIGALRM, SIG_IGN)) == SIG_ERR)
-    logmsg("cannot install SIGALRM handler: 5s", strerror(ERRNO));
+    logmsg("cannot install SIGALRM handler: %s", strerror(ERRNO));
 #endif
 #ifdef SIGINT
   /* handle SIGINT signal with our exit_signal_handler */
   if((old_sigint_handler = signal(SIGINT, exit_signal_handler)) == SIG_ERR)
-    logmsg("cannot install SIGINT handler: 5s", strerror(ERRNO));
+    logmsg("cannot install SIGINT handler: %s", strerror(ERRNO));
   else
     siginterrupt(SIGINT, 1);
 #endif
 #ifdef SIGTERM
   /* handle SIGTERM signal with our exit_signal_handler */
   if((old_sigterm_handler = signal(SIGTERM, exit_signal_handler)) == SIG_ERR)
-    logmsg("cannot install SIGTERM handler: 5s", strerror(ERRNO));
+    logmsg("cannot install SIGTERM handler: %s", strerror(ERRNO));
   else
     siginterrupt(SIGTERM, 1);
 #endif
@@ -269,7 +272,7 @@ static ssize_t fullread(int filedes, void *buffer, size_t nbytes)
   } while((size_t)nread < nbytes);
 
   if(verbose)
-    logmsg("read %ld bytes", (long)nread);
+    logmsg("read %zd bytes", nread);
 
   return nread;
 }
@@ -313,7 +316,7 @@ static ssize_t fullwrite(int filedes, const void *buffer, size_t nbytes)
   } while((size_t)nwrite < nbytes);
 
   if(verbose)
-    logmsg("wrote %ld bytes", (long)nwrite);
+    logmsg("wrote %zd bytes", nwrite);
 
   return nwrite;
 }
@@ -403,13 +406,13 @@ static bool juggle(curl_socket_t *sockfdp,
   fd_set fds_read;
   fd_set fds_write;
   fd_set fds_err;
-  curl_socket_t sockfd;
-  curl_socket_t maxfd;
+  curl_socket_t sockfd = CURL_SOCKET_BAD;
+  curl_socket_t maxfd = CURL_SOCKET_BAD;
   ssize_t rc;
   ssize_t nread_socket;
   ssize_t bytes_written;
   ssize_t buffer_len;
-  int error;
+  int error = 0;
 
  /* 'buffer' is this excessively large only to be able to support things like
     test 1003 which tests exceedingly large server response lines */
@@ -542,7 +545,7 @@ static bool juggle(curl_socket_t *sockfdp,
     else if(!memcmp("PORT", buffer, 4)) {
       /* Question asking us what PORT number we are listening to.
          Replies to PORT with "IPv[num]/[port]" */
-      sprintf((char *)buffer, "IPv%d/%d\n", use_ipv6?6:4, (int)port);
+      sprintf((char *)buffer, "%s/%d\n", ipv_inuse, (int)port);
       buffer_len = (ssize_t)strlen((char *)buffer);
       snprintf(data, sizeof(data), "PORT\n%04x\n", buffer_len);
       if(!write_stdout(data, 10))
@@ -565,11 +568,11 @@ static bool juggle(curl_socket_t *sockfdp,
 
       buffer_len = (ssize_t)strtol((char *)buffer, NULL, 16);
       if (buffer_len > (ssize_t)sizeof(buffer)) {
-        logmsg("ERROR: Buffer size (%ld bytes) too small for data size "
-               "(%ld bytes)", (long)sizeof(buffer), (long)buffer_len);
+        logmsg("ERROR: Buffer size (%zu bytes) too small for data size "
+               "(%zd bytes)", sizeof(buffer), buffer_len);
         return FALSE;
       }
-      logmsg("> %d bytes data, server => client", buffer_len);
+      logmsg("> %zd bytes data, server => client", buffer_len);
 
       if(!read_stdin(buffer, buffer_len))
         return FALSE;
@@ -585,7 +588,7 @@ static bool juggle(curl_socket_t *sockfdp,
         /* send away on the socket */
         bytes_written = swrite(sockfd, buffer, buffer_len);
         if(bytes_written != buffer_len) {
-          logmsg("Not all data was sent. Bytes to send: %d sent: %d", 
+          logmsg("Not all data was sent. Bytes to send: %zd sent: %zd",
                  buffer_len, bytes_written);
         }
       }
@@ -650,7 +653,7 @@ static bool juggle(curl_socket_t *sockfdp,
     if(!write_stdout(buffer, nread_socket))
       return FALSE;
 
-    logmsg("< %d bytes data, client => server", nread_socket);
+    logmsg("< %zd bytes data, client => server", nread_socket);
     lograw(buffer, nread_socket);
   }
 
@@ -805,13 +808,17 @@ int main(int argc, char *argv[])
     }
     else if(!strcmp("--ipv6", argv[arg])) {
 #ifdef ENABLE_IPV6
-      use_ipv6=TRUE;
+      ipv_inuse = "IPv6";
+      use_ipv6 = TRUE;
 #endif
       arg++;
     }
     else if(!strcmp("--ipv4", argv[arg])) {
       /* for completeness, we support this option as well */
-      use_ipv6=FALSE;
+#ifdef ENABLE_IPV6
+      ipv_inuse = "IPv4";
+      use_ipv6 = FALSE;
+#endif
       arg++;
     }
     else if(!strcmp("--port", argv[arg])) {
@@ -906,7 +913,7 @@ int main(int argc, char *argv[])
 #endif /* ENABLE_IPV6 */
     if(rc) {
       error = SOCKERRNO;
-      logmsg("Error connecting to port %d: (%d) %s",
+      logmsg("Error connecting to port %hu: (%d) %s",
              connectport, error, strerror(error));
       goto sockfilt_cleanup;
     }
@@ -921,13 +928,12 @@ int main(int argc, char *argv[])
     msgsock = CURL_SOCKET_BAD; /* no stream socket yet */
   }
 
-  logmsg("Running IPv%d version",
-         (use_ipv6?6:4));
+  logmsg("Running %s version", ipv_inuse);
 
   if(connectport)
-    logmsg("Connected to port %d", connectport);
+    logmsg("Connected to port %hu", connectport);
   else
-    logmsg("Listening on port %d", port);
+    logmsg("Listening on port %hu", port);
 
   wrotepidfile = write_pidfile(pidname);
   if(!wrotepidfile)
